@@ -3,8 +3,5 @@ from ..type import Type
 
 class VisibleString(Type):
     def __init__(self):
-        super().__init__()
+        super(VisibleString, self).__init__()
         self.typereference = "VisibleString"
-
-    def __repr__(self):
-        return '\t' + super().__repr__() + '\n'
